@@ -50,18 +50,18 @@ def BrowserGCM(headless=True):
             display.start()
         except Exception as e:
             print(f'Failed loading virtual display {e}')
-            raise BrowserException(e)
+            raise BrowserException(f'Failed loading virtual display {e}')
         try:
             return webdriver.Chrome(options=chrome_options)
         except Exception as e:
-            print('Webdrivewr.chrome failed {e}')
-            raise RuntimeError(e)
+            print(f'Webdrivewr.chrome failed {e}')
+            raise BrowserException(f'Webdrivewr.chrome failed {e}')
     try:
         browser_cm = init_browser(headless)
         yield browser_cm
     except Exception as exc:
         print(f'Failed init browser ?? {exc}')
-        raise BrowserException(exc)
+        raise BrowserException(f'Failed init browser ?? {exc}')
     finally:
         if browser_cm:
             browser_cm.quit()
